@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { dockerConfigExample } from './examples';
+import { dockerConfigExample, devWorkspaceResourcesExample } from './examples';
 import { JSONSchema7 } from 'json-schema';
 
 export const authenticationHeaderSchema: JSONSchema7 = {
@@ -149,6 +149,39 @@ export const yamlResolverSchema: JSONSchema7 = {
   required: ['url'],
 };
 
+export const devWorkspaceResourcesSchema: JSONSchema7 = {
+  type: 'object',
+  properties: {
+    devfileContent: {
+      type: 'string',
+    },
+    editorPath: {
+      type: 'string',
+    },
+    pluginRegistryUrl: {
+      type: 'string',
+    },
+    editorEntry: {
+      type: 'string',
+    },
+    projects: {
+      type: 'array',
+      items: {
+        type: 'object',
+        properties: {
+          name: {
+            type: 'string',
+          },
+          location: {
+            type: 'string',
+          },
+        },
+      },
+    },
+  },
+  examples: [devWorkspaceResourcesExample],
+};
+
 export const devworkspaceSchema: JSONSchema7 = {
   type: 'object',
   properties: {
