@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -48,7 +48,7 @@ describe('dwPlugins selectors', () => {
 
   it('should return all plugins and errors', () => {
     const fakeStore = new FakeStoreBuilder()
-      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
+      .withDwPlugins(plugins, false, 'default editor fetching error')
       .build() as MockStoreEnhanced<
       AppState,
       ThunkDispatch<AppState, undefined, store.KnownAction>
@@ -62,7 +62,7 @@ describe('dwPlugins selectors', () => {
 
   it('should return array of plugins', () => {
     const fakeStore = new FakeStoreBuilder()
-      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
+      .withDwPlugins(plugins, false, 'default editor fetching error')
       .build() as MockStoreEnhanced<
       AppState,
       ThunkDispatch<AppState, undefined, store.KnownAction>
@@ -89,7 +89,7 @@ describe('dwPlugins selectors', () => {
 
   it('should return an error related to default editor fetching', () => {
     const fakeStore = new FakeStoreBuilder()
-      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
+      .withDwPlugins(plugins, false, 'default editor fetching error')
       .build() as MockStoreEnhanced<
       AppState,
       ThunkDispatch<AppState, undefined, store.KnownAction>
