@@ -15,6 +15,7 @@ import { Action, Reducer } from 'redux';
 import { AppThunk } from '../..';
 import { container } from '../../../inversify.config';
 import { injectKubeConfig } from '../../../services/dashboard-backend-client/devWorkspaceApi';
+import { podmanLogin } from '../../../services/dashboard-backend-client/devWorkspaceApi';
 import { WebsocketClient } from '../../../services/dashboard-backend-client/websocketClient';
 import devfileApi, { isDevWorkspace } from '../../../services/devfileApi';
 import { devWorkspaceKind } from '../../../services/devfileApi/devWorkspace';
@@ -47,6 +48,7 @@ import OAuthService from '../../../services/oauth';
 import { FactoryParams } from '../../../containers/Loader/buildFactoryParams';
 import { getEditor } from '../../DevfileRegistries/getEditor';
 import { selectApplications } from '../../ClusterInfo/selectors';
+import { cloneDeep } from 'lodash';
 
 export const onStatusChangeCallbacks = new Map<string, (status: string) => void>();
 
@@ -640,7 +642,11 @@ export const actionCreators: ActionCreators = {
         if (devWorkspaceResource === undefined) {
           throw new Error('Failed to find a DevWorkspace in the fetched resources.');
         }
-
+        if (devWorkspaceResource.metadata) {
+          if (!devWorkspaceResource.metadata.annotations) {
+            devWorkspaceResource.metadata.annotations = {};
+          }
+        }
         devWorkspaceTemplateResource = resources.find(
           resource => resource.kind === 'DevWorkspaceTemplate',
         ) as devfileApi.DevWorkspaceTemplate;
@@ -672,7 +678,7 @@ export const actionCreators: ActionCreators = {
         const { status } = message;
 
         const errorMessage = `WebSocket(DEV_WORKSPACE): status code ${status.code}, reason: ${status.message}`;
-        console.warn(errorMessage);
+        console.debug(errorMessage);
 
         if (status.code !== 200) {
           /* in case of error status trying to fetch all devWorkspaces and re-subscribe to websocket channel */
@@ -689,11 +695,9 @@ export const actionCreators: ActionCreators = {
             const state = getState();
             return selectDevWorkspacesResourceVersion(state);
           };
-          websocketClient.subscribeToChannel(
-            api.webSocket.Channel.DEV_WORKSPACE,
-            namespace,
+          websocketClient.subscribeToChannel(api.webSocket.Channel.DEV_WORKSPACE, namespace, {
             getResourceVersion,
-          );
+          });
         }
         return;
       }
@@ -753,14 +757,16 @@ export const actionCreators: ActionCreators = {
           }
         }
 
-        // inject the kube config
         if (
           phase === DevWorkspaceStatus.RUNNING &&
           phase !== prevPhase &&
           devworkspaceId !== undefined
         ) {
           try {
+            // inject the kube config
             await injectKubeConfig(workspace.metadata.namespace, devworkspaceId);
+            // inject the 'podman login'
+            await podmanLogin(workspace.metadata.namespace, devworkspaceId);
           } catch (e) {
             console.error(e);
           }
