@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -18,9 +18,10 @@ import { selectRunningWorkspacesLimit } from '../../ClusterConfig/selectors';
 const selectState = (state: AppState) => state.devWorkspaces;
 export const selectDevWorkspacesState = selectState;
 
-export const selectDevWorkspacesResourceVersion = createSelector(selectState, state => {
-  return state.resourceVersion;
-});
+export const selectDevWorkspacesResourceVersion = createSelector(
+  selectState,
+  state => state.resourceVersion,
+);
 
 export const selectAllDevWorkspaces = createSelector(selectState, state => {
   return state.workspaces;
@@ -28,13 +29,13 @@ export const selectAllDevWorkspaces = createSelector(selectState, state => {
 
 export const selectDevWorkspacesError = createSelector(selectState, state => state.error);
 
-export const selectRunningDevWorkspaces = createSelector(selectState, state => {
-  return state.workspaces.filter(
+export const selectRunningDevWorkspaces = createSelector(selectState, state =>
+  state.workspaces.filter(
     workspace =>
       workspace.status?.phase === DevWorkspaceStatus.STARTING ||
       workspace.status?.phase === DevWorkspaceStatus.RUNNING,
-  );
-});
+  ),
+);
 
 export const selectRunningDevWorkspacesLimitExceeded = createSelector(
   selectRunningDevWorkspaces,
@@ -42,3 +43,10 @@ export const selectRunningDevWorkspacesLimitExceeded = createSelector(
   (runningDevWorkspaces, runningWorkspacesLimit) =>
     runningWorkspacesLimit !== -1 && runningDevWorkspaces.length >= runningWorkspacesLimit,
 );
+
+export const selectStartedWorkspaces = createSelector(
+  selectState,
+  state => state.startedWorkspaces,
+);
+
+export const selectDevWorkspaceWarnings = createSelector(selectState, state => state.warnings);
